==> Veil-common-1.20.1-1.0.0.282-sources.jar: foundry/veil/impl/client/render/shader/SimpleShaderProcessor.java <==
package foundry.veil.impl.client.render.shader;

import foundry.veil.api.client.render.shader.definition.ShaderPreDefinitions;
import foundry.veil.api.client.render.shader.processor.ShaderCPreprocessor;
import foundry.veil.api.client.render.shader.processor.ShaderCustomProcessor;
import foundry.veil.api.client.render.shader.processor.ShaderModifyProcessor;
import foundry.veil.api.client.render.shader.processor.ShaderPreProcessor;
import foundry.veil.api.client.render.shader.program.ProgramDefinition;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.Nullable;

import java.io.IOException;
import java.util.Collections;
import java.util.Set;
import net.minecraft.class_2960;
import net.minecraft.class_5912;

/**
 * Allows vanilla and sodium shaders to use shader modifications.
 */
@ApiStatus.Internal
public class SimpleShaderProcessor {

    private static ShaderPreProcessor processor;

    public static void setup(class_5912 resourceProvider) {
        processor = ShaderPreProcessor.allOf(new ShaderCPreprocessor(), new ShaderModifyProcessor(), new ShaderCustomProcessor(resourceProvider), new ShaderCPreprocessor());
    }

    public static void free() {
        processor = null;
    }

    public static String modify(@Nullable class_2960 name, String source) throws IOException {
        if (processor == null) {
            throw new NullPointerException("Processor not initialized");
        }
        return processor.modify(new Context(name), source);
    }

    private record Context(class_2960 name) implements ShaderPreProcessor.Context {

        @Override
        public String modify(@Nullable class_2960 name, String source) throws IOException {
            return processor.modify(new Context(name), source);
        }

        @Override
        public void addUniformBinding(String name, int binding) {
            throw new UnsupportedOperationException();
        }

        @Override
        public void addDefinitionDependency(String name) {
            throw new UnsupportedOperationException();
        }

        @Override
        public void addInclude(class_2960 name) {
        }

        @Override
        public Set<class_2960> includes() {
            return Collections.emptySet();
        }

        @Override
        public @Nullable class_2960 name() {
            return this.name;
        }

        @Override
        public boolean isSourceFile() {
            return true;
        }

        @Override
        public @Nullable ProgramDefinition definition() {
            return null;
        }

        @Override
        public @Nullable ShaderPreDefinitions preDefinitions() {
            return null;
        }
    }
}

==> Veil-common-1.20.1-1.0.0.295-sources.jar: foundry/veil/impl/client/render/shader/SimpleShaderProcessor.java <==
package foundry.veil.impl.client.render.shader;

import foundry.veil.api.client.render.shader.definition.ShaderPreDefinitions;
import foundry.veil.api.client.render.shader.processor.ShaderCustomProcessor;
import foundry.veil.api.client.render.shader.processor.ShaderModifyProcessor;
import foundry.veil.api.client.render.shader.processor.ShaderPreProcessor;
import foundry.veil.api.client.render.shader.program.ProgramDefinition;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.Nullable;

import java.io.IOException;
import java.util.Collections;
import java.util.Set;
import net.minecraft.class_2960;
import net.minecraft.class_5912;

/**
 * Allows vanilla and sodium shaders to use shader modifications.
 */
@ApiStatus.Internal
public class SimpleShaderProcessor {

    private static ShaderPreProcessor processor;

    public static void setup(class_5912 resourceProvider) {
        processor = ShaderPreProcessor.allOf(new ShaderModifyProcessor(), new ShaderCustomProcessor(resourceProvider));
    }

    public static void free() {
        processor = null;
    }

    public static String modify(@Nullable class_2960 name, String source) throws IOException {
        if (processor == null) {
            throw new NullPointerException("Processor not initialized");
        }
        return processor.modify(new Context(name), source);
    }

    private record Context(class_2960 name) implements ShaderPreProcessor.Context {

        @Override
        public String modify(@Nullable class_2960 name, String source) throws IOException {
            return processor.modify(new Context(name), source);
        }

        @Override
        public void addUniformBinding(String name, int binding) {
            throw new UnsupportedOperationException();
        }

        @Override
        public void addDefinitionDependency(String name) {
            throw new UnsupportedOperationException();
        }

        @Override
        public void addInclude(class_2960 name) {
        }

        @Override
        public Set<class_2960> includes() {
            return Collections.emptySet();
        }

        @Override
        public @Nullable class_2960 name() {
            return this.name;
        }

        @Override
        public boolean isSourceFile() {
            return true;
        }

        @Override
        public @Nullable ProgramDefinition definition() {
            return null;
        }

        @Override
        public @Nullable ShaderPreDefinitions preDefinitions() {
            return null;
        }
    }
}
